@@ -206,6 +206,8 @@ def create_connection(url, timeout=None, **options):
              "http_proxy_host" - http proxy host name.
              "http_proxy_port" - http proxy port. If not set, set to 80.
              "enable_multithread" -> enable lock for multithread.
+             "sockopt" -> socket options
+             "sslopt" -> ssl option
     """
     sockopt = options.get("sockopt", [])
     sslopt = options.get("sslopt", {})
@@ -457,8 +459,10 @@ class WebSocket(object):
                 if os.path.isfile(certPath):
                     sslopt['ca_certs'] = certPath
                 sslopt.update(self.sslopt)
+                check_hostname = sslopt.pop('check_hostname', True)
                 self.sock = ssl.wrap_socket(self.sock, **sslopt)
-                if sslopt["cert_reqs"] != ssl.CERT_NONE:
+                if (sslopt["cert_reqs"] != ssl.CERT_NONE
+                        and check_hostname):
                     match_hostname(self.sock.getpeercert(), hostname)
             else:
                 raise WebSocketException("SSL not available.")
